LOG_CONFIG = {'version': 1, 'disable_existing_loggers': False, 'formatters': {'verbose': {'format': '%(asctime)s - %(threadName)s -  %(name)s - %(levelname)s - %(message)s'}}, 'handlers': {'console': {'class': 'logging.StreamHandler', 'level': 'DEBUG', 'formatter': 'verbose', 'stream': 'ext://sys.stdout'}, 'file_handler': {'class': 'logging.handlers.RotatingFileHandler', 'level': 'INFO', 'formatter': 'verbose', 'filename': 'info.log', 'maxBytes': 10485760, 'backupCount': 10, 'encoding': 'utf8'}}, 'loggers': {'my_module': {'level': 'DEBUG', 'handlers': ['console'], 'propagate': 'no'}}, 'root': {'level': 'INFO', 'handlers': ['console', 'file_handler']}}

SCHEMA = {'$schema': 'http://json-schema.org/draft-07/schema#', 'definitions': {'geometry': {'$id': '#geometry', 'type': 'object', 'properties': {'type': {'type': 'string', 'enum': ['mesh', 'box', 'plane', 'sphere']}}, 'required': ['type'], 'allOf': [{'if': {'properties': {'type': {'const': 'mesh'}}, 'required': ['type']}, 'then': {'properties': {'path': {'type': 'string'}}, 'required': ['path']}}, {'if': {'properties': {'type': {'const': 'box'}}, 'required': ['type']}, 'then': {'properties': {'size': {'type': 'array', 'items': {'type': 'number', 'exclusiveMinimum': 0}, 'minItems': 3, 'maxItems': 3}}, 'required': ['size']}}, {'if': {'properties': {'type': {'const': 'plane'}}, 'required': ['type']}, 'then': {'properties': {'size': {'type': 'array', 'items': {'type': 'number', 'exclusiveMinimum': 0}, 'minItems': 2, 'maxItems': 2}}, 'required': ['size']}}, {'if': {'properties': {'type': {'const': 'sphere'}}, 'required': ['type']}, 'then': {'properties': {'radius': {'type': 'number', 'exclusiveMinimum': 0}}, 'required': ['radius']}}]}, 'visual': {'$id': '#visual', 'type': 'object', 'properties': {'pose': {'type': 'array', 'items': {'type': 'number'}, 'minItems': 6, 'maxItems': 6}, 'colour': {'type': 'array', 'items': {'type': 'number'}, 'minItems': 3, 'maxItems': 3}, 'mesh': {'type': 'string'}, 'geometry': {'$ref': '#/definitions/geometry'}}, 'allOf': [{'if': {'not': {'properties': {'pose': {'type': 'array', 'items': {'type': 'number'}, 'minItems': 6, 'maxItems': 6}, 'colour': {'type': 'array', 'items': {'type': 'number'}, 'minItems': 3, 'maxItems': 3}, 'mesh': {'type': 'string'}}, 'required': ['mesh']}}, 'then': {'required': ['geometry']}}]}, 'joint': {'$id': '#joint', 'type': 'object', 'properties': {'name': {'type': 'string'}, 'type': {'type': 'string', 'enum': ['prismatic', 'revolute']}, 'parent': {'type': 'string'}, 'child': {'type': 'string'}, 'axis': {'type': 'array', 'items': {'type': 'number'}, 'minItems': 3, 'maxItems': 3}, 'origin': {'type': 'array', 'items': {'type': 'number'}, 'minItems': 3, 'maxItems': 3}, 'lower_limit': {'type': 'number'}, 'upper_limit': {'type': 'number'}, 'home_offset': {'type': 'number'}, 'description': {'type': 'string'}}, 'required': ['name', 'type', 'parent', 'child', 'axis', 'origin', 'lower_limit', 'upper_limit']}, 'detector': {'$id': '#detector', 'type': 'object', 'properties': {'name': {'type': 'string'}, 'default_collimator': {'type': 'string'}, 'diffracted_beam': {'type': 'array', 'items': {'type': 'number'}, 'minItems': 3, 'maxItems': 3}, 'positioner': {'type': 'string'}}, 'required': ['name', 'diffracted_beam']}, 'collimator': {'$id': '#collimator', 'type': 'object', 'properties': {'name': {'type': 'string'}, 'detector': {'type': 'string'}, 'aperture': {'type': 'array', 'items': {'type': 'number'}, 'minItems': 2, 'maxItems': 2}, 'visual': {'$ref': '#/definitions/visual'}}, 'required': ['name', 'detector', 'aperture', 'visual']}, 'hardware': {'$id': '#hardware', 'type': 'object', 'properties': {'name': {'type': 'string'}, 'visual': {'$ref': '#/definitions/visual'}}, 'required': ['name', 'visual']}, 'link': {'$id': '#link', 'type': 'object', 'properties': {'name': {'type': 'string'}, 'visual': {'$ref': '#/definitions/visual'}}, 'required': ['name']}, 'positioner': {'$id': '#positioner', 'type': 'object', 'properties': {'name': {'type': 'string'}, 'base': {'type': 'array', 'items': {'type': 'number'}, 'minItems': 6, 'maxItems': 6}, 'tool': {'type': 'array', 'items': {'type': 'number'}, 'minItems': 6, 'maxItems': 6}, 'custom_order': {'type': 'array', 'items': {'type': 'string'}}, 'joints': {'type': 'array', 'items': {'$ref': '#/definitions/joint'}, 'minItems': 1}, 'links': {'type': 'array', 'items': {'$ref': '#/definitions/link'}, 'minItems': 2}}, 'required': ['name', 'joints', 'links']}, 'positioning_stack': {'$id': '#positioning_stack', 'type': 'object', 'properties': {'name': {'type': 'string'}, 'positioners': {'type': 'array', 'items': {'type': 'string'}, 'minItems': 1}}, 'required': ['name', 'positioners']}}, 'title': 'Instrument', 'description': 'SScanSS 2 instrument', 'type': 'object', 'properties': {'instrument': {'type': 'object', 'properties': {'name': {'description': 'The unique name of the instrument', 'type': 'string'}, 'version': {'description': 'The version number of file', 'type': 'string'}, 'script_template': {'description': 'The path of script template', 'type': 'string'}, 'gauge_volume': {'description': 'The centre of gauge volume', 'type': 'array', 'items': {'type': 'number'}, 'minItems': 3, 'maxItems': 3}, 'incident_jaws': {'type': 'object', 'properties': {'aperture': {'type': 'array', 'items': {'type': 'number'}, 'minItems': 2, 'maxItems': 2}, 'aperture_lower_limit': {'type': 'array', 'items': {'type': 'number'}, 'minItems': 2, 'maxItems': 2}, 'aperture_upper_limit': {'type': 'array', 'items': {'type': 'number'}, 'minItems': 2, 'maxItems': 2}, 'beam_direction': {'type': 'array', 'items': {'type': 'number'}, 'minItems': 3, 'maxItems': 3}, 'beam_source': {'type': 'array', 'items': {'type': 'number'}, 'minItems': 3, 'maxItems': 3}, 'positioner': {'type': 'string'}, 'visual': {'$ref': '#/definitions/visual'}}, 'required': ['aperture', 'aperture_lower_limit', 'aperture_upper_limit', 'beam_direction', 'beam_source', 'visual']}, 'detectors': {'type': 'array', 'items': {'$ref': '#/definitions/detector'}, 'minItems': 1}, 'collimators': {'type': 'array', 'items': {'$ref': '#/definitions/collimator'}}, 'positioning_stacks': {'type': 'array', 'items': {'$ref': '#/definitions/positioning_stack'}, 'minItems': 1}, 'positioners': {'type': 'array', 'items': {'$ref': '#/definitions/positioner'}, 'minItems': 1}, 'fixed_hardware': {'type': 'array', 'items': {'$ref': '#/definitions/hardware'}}}, 'required': ['name', 'version', 'gauge_volume', 'incident_jaws', 'detectors', 'positioning_stacks', 'positioners']}}, 'required': ['instrument']}
